pub async fn create_chart(
configuration: &Configuration,
ship_symbol: &str,
) -> Result<ResponseContent<CreateChartSuccess>, Error<CreateChartError>>Expand description
Command a ship to chart the waypoint at its current location. Most waypoints in the universe are uncharted by default. These waypoints have their traits hidden until they have been charted by a ship. Charting a waypoint will record your agent as the one who created the chart, and all other agents would also be able to see the waypoint’s traits.