patch_ship_nav

Function patch_ship_nav 

pub async fn patch_ship_nav(
    configuration: &Configuration,
    ship_symbol: &str,
    patch_ship_nav_request: Option<PatchShipNavRequest>,
) -> Result<ResponseContent<PatchShipNavSuccess>, Error<PatchShipNavError>>
Update the nav configuration of a ship. Currently only supports configuring the Flight Mode of the ship, which affects its speed and fuel consumption.