pub struct ContractDeliverGood {
pub trade_symbol: String,
pub destination_symbol: String,
pub units_required: i32,
pub units_fulfilled: i32,
}Expand description
The details of a delivery contract. Includes the type of good, units needed, and the destination.
Fields
trade_symbol: StringThe symbol of the trade good to deliver.
destination_symbol: StringThe destination where goods need to be delivered.
units_required: i32The number of units that need to be delivered on this contract.
units_fulfilled: i32The number of units fulfilled on this contract.
Implementations