pub struct ContractPayment {
pub on_accepted: i32,
pub on_fulfilled: i32,
}Expand description
Payments for the contract.
Fields
on_accepted: i32The amount of credits received up front for accepting the contract.
on_fulfilled: i32The amount of credits received when the contract is fulfilled.
Implementations
Sourceimpl ContractPayment
impl ContractPayment
Sourcepub fn new(on_accepted: i32, on_fulfilled: i32) -> ContractPayment
pub fn new(on_accepted: i32, on_fulfilled: i32) -> ContractPayment
Create value with optional fields set to None.