pub struct DeliverContractRequest {
pub ship_symbol: String,
pub trade_symbol: String,
pub units: i32,
}Expand description
Fields
ship_symbol: StringSymbol of a ship located in the destination to deliver a contract and that has a good to deliver in its cargo.
trade_symbol: StringThe symbol of the good to deliver.
units: i32Amount of units to deliver.
Implementations