pub struct JumpGate {
pub jump_range: f32,
pub faction_symbol: Option<String>,
pub connected_systems: Vec<ConnectedSystem>,
}Expand description
Fields
jump_range: f32The maximum jump range of the gate.
faction_symbol: Option<String>The symbol of the faction that owns the gate.
connected_systems: Vec<ConnectedSystem>The systems within range of the gate that have a corresponding gate.
Implementations