pub struct Market {
pub symbol: String,
pub exports: Vec<TradeGood>,
pub imports: Vec<TradeGood>,
pub exchange: Vec<TradeGood>,
pub transactions: Option<Vec<MarketTransaction>>,
pub trade_goods: Option<Vec<MarketTradeGood>>,
}Expand description
Fields
symbol: StringThe symbol of the market. The symbol is the same as the waypoint where the market is located.
exports: Vec<TradeGood>The list of goods that are exported from this market.
imports: Vec<TradeGood>The list of goods that are sought as imports in this market.
exchange: Vec<TradeGood>The list of goods that are bought and sold between agents at this market.
transactions: Option<Vec<MarketTransaction>>The list of recent transactions at this market. Visible only when a ship is present at the market.
trade_goods: Option<Vec<MarketTradeGood>>The list of goods that are traded at this market. Visible only when a ship is present at the market.
Implementations