pub struct MarketTradeGood {
pub symbol: String,
pub trade_volume: u32,
pub supply: Supply,
pub purchase_price: u32,
pub sell_price: u32,
}Expand description
Fields
symbol: StringThe symbol of the trade good.
trade_volume: u32The typical volume flowing through the market for this type of good. The larger the trade volume, the more stable prices will be.
supply: SupplyA rough estimate of the total supply of this good in the marketplace.
purchase_price: u32The price at which this good can be purchased from the market.
sell_price: u32The price at which this good can be sold to the market.
Implementations