RefuelShipRequest

Struct RefuelShipRequest 

pub struct RefuelShipRequest {
    pub units: Option<u32>,
}
Fields

units: Option<u32>

The amount of fuel to fill in the ship’s tanks. When not specified, the ship will be refueled to its maximum fuel capacity. If the amount specified is greater than the ship’s remaining capacity, the ship will only be refueled to its maximum fuel capacity. The amount specified is not in market units but in ship fuel units.

Implementations

Source

impl RefuelShipRequest

pub fn new() -> RefuelShipRequest

Create value with optional fields set to None.