pub struct ShipCargo {
pub capacity: u32,
pub units: u32,
pub inventory: Vec<ShipCargoItem>,
}Expand description
Ship cargo details.
Fields
capacity: u32The max number of items that can be stored in the cargo hold.
units: u32The number of items currently stored in the cargo hold.
inventory: Vec<ShipCargoItem>The items currently in the cargo hold.
Implementations