ShipCrew

Struct ShipCrew 

pub struct ShipCrew {
    pub current: i32,
    pub required: i32,
    pub capacity: i32,
    pub rotation: Rotation,
    pub morale: u32,
    pub wages: u32,
}
The ship’s crew service and maintain the ship’s systems and equipment.

Fields

current: i32

The current number of crew members on the ship.

required: i32

The minimum number of crew members required to maintain the ship.

capacity: i32

The maximum number of crew members the ship can support.

rotation: Rotation

The rotation of crew shifts. A stricter shift improves the ship’s performance. A more relaxed shift improves the crew’s morale.

morale: u32

A rough measure of the crew’s morale. A higher morale means the crew is happier and more productive. A lower morale means the ship is more prone to accidents.

wages: u32

The amount of credits per crew member paid per hour. Wages are paid when a ship docks at a civilized waypoint.

Implementations

Source

impl ShipCrew

pub fn new( current: i32, required: i32, capacity: i32, rotation: Rotation, morale: u32, wages: u32, ) -> ShipCrew

Create value with optional fields set to None.