ShipFrame

Struct ShipFrame 

pub struct ShipFrame {
    pub symbol: Symbol,
    pub name: String,
    pub description: String,
    pub condition: Option<u32>,
    pub module_slots: u32,
    pub mounting_points: u32,
    pub fuel_capacity: u32,
    pub requirements: ShipRequirements,
}
The frame of the ship. The frame determines the number of modules and mounting points of the ship, as well as base fuel capacity. As the condition of the frame takes more wear, the ship will become more sluggish and less maneuverable.

Fields

symbol: Symbol

Symbol of the frame.

name: String

Name of the frame.

description: String

Description of the frame.

condition: Option<u32>

Condition is a range of 0 to 100 where 0 is completely worn out and 100 is brand new.

module_slots: u32

The amount of slots that can be dedicated to modules installed in the ship. Each installed module take up a number of slots, and once there are no more slots, no new modules can be installed.

mounting_points: u32

The amount of slots that can be dedicated to mounts installed in the ship. Each installed mount takes up a number of points, and once there are no more points remaining, no new mounts can be installed.

fuel_capacity: u32

The maximum amount of fuel that can be stored in this ship. When refueling, the ship will be refueled to this amount.

requirements: ShipRequirements

Implementations

Source

impl ShipFrame

pub fn new( symbol: Symbol, name: String, description: String, module_slots: u32, mounting_points: u32, fuel_capacity: u32, requirements: ShipRequirements, ) -> ShipFrame

Create value with optional fields set to None.