pub struct ShipNavRouteWaypoint {
pub symbol: String,
pub type: WaypointType,
pub system_symbol: String,
pub x: i32,
pub y: i32,
}Expand description
The destination or departure of a ships nav route.
Fields
symbol: StringThe symbol of the waypoint.
type: WaypointTypesystem_symbol: StringThe symbol of the system the waypoint is in.
x: i32Position in the universe in the x axis.
y: i32Position in the universe in the y axis.
Implementations
Sourcepub fn new(
symbol: String,
type: WaypointType,
system_symbol: String,
x: i32,
y: i32,
) -> ShipNavRouteWaypoint
pub fn new( symbol: String, type: WaypointType, system_symbol: String, x: i32, y: i32, ) -> ShipNavRouteWaypoint
Create value with optional fields set to None.