pub struct ShipReactor {
pub symbol: Symbol,
pub name: String,
pub description: String,
pub condition: Option<u32>,
pub power_output: u32,
pub requirements: ShipRequirements,
}Expand description
The reactor of the ship. The reactor is responsible for powering the ship’s systems and weapons.
Fields
symbol: SymbolSymbol of the reactor.
name: StringName of the reactor.
description: StringDescription of the reactor.
condition: Option<u32>Condition is a range of 0 to 100 where 0 is completely worn out and 100 is brand new.
power_output: u32The amount of power provided by this reactor. The more power a reactor provides to the ship, the lower the cooldown it gets when using a module or mount that taxes the ship’s power.
requirements: ShipRequirementsImplementations
Sourceimpl ShipReactor
impl ShipReactor
Sourcepub fn new(
symbol: Symbol,
name: String,
description: String,
power_output: u32,
requirements: ShipRequirements,
) -> ShipReactor
pub fn new( symbol: Symbol, name: String, description: String, power_output: u32, requirements: ShipRequirements, ) -> ShipReactor
Create value with optional fields set to None.