pub struct Shipyard {
pub symbol: String,
pub ship_types: Vec<ShipyardShipTypesInner>,
pub transactions: Option<Vec<ShipyardTransaction>>,
pub ships: Option<Vec<ShipyardShip>>,
}Expand description
Fields
symbol: StringThe symbol of the shipyard. The symbol is the same as the waypoint where the shipyard is located.
ship_types: Vec<ShipyardShipTypesInner>The list of ship types available for purchase at this shipyard.
transactions: Option<Vec<ShipyardTransaction>>The list of recent transactions at this shipyard.
ships: Option<Vec<ShipyardShip>>The ships that are currently available for purchase at the shipyard.
Implementations