pub struct Survey {
pub signature: String,
pub symbol: String,
pub deposits: Vec<SurveyDeposit>,
pub expiration: String,
pub size: Size,
}Expand description
A resource survey of a waypoint, detailing a specific extraction location and the types of resources that can be found there.
Fields
signature: StringA unique signature for the location of this survey. This signature is verified when attempting an extraction using this survey.
symbol: StringThe symbol of the waypoint that this survey is for.
deposits: Vec<SurveyDeposit>A list of deposits that can be found at this location.
expiration: StringThe date and time when the survey expires. After this date and time, the survey will no longer be available for extraction.
size: SizeThe size of the deposit. This value indicates how much can be extracted from the survey before it is exhausted.
Implementations