pub async fn remove_mount(
configuration: &Configuration,
ship_symbol: &str,
remove_mount_request: Option<RemoveMountRequest>,
) -> Result<ResponseContent<RemoveMountSuccess>, Error<RemoveMountError>>Expand description
Remove a mount from a ship. The ship must be docked in a waypoint that has the Shipyard trait, and must have the desired mount that it wish to remove installed. A removal fee will be deduced from the agent by the Shipyard.